from tier import Tier


class OozieMaster(Tier):
    tier = "oozie-master"
    modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "pig", "tapp2", "cloudman"]
    def __init__(self, subparser):
        super(OozieMaster, self).__init__(subparser)
